The Atlantic Online | April 1940 | But—I'm a Conservative!

The Atlantic Monthly | April 1940

# But—I'm a Conservative!

"Our job is to prove right here in America that democracy means, not destructive wrangling, but effective cooperation in solving our spiritual and economic problems. Can this be too much to hope from American youth?"

.....

'Men too often, in their revenge, set the example of doing away with those general laws to which all alike can look for salvation in adversity.'
—Thucydides, 426 B.C.

hy should any young man want to be a conservative, on a globe where so much needs changing? I can best answer in a roundabout way with a few facts about myself. I am twenty-three years of age, unemployed, short of cash. For six years I have studied at Harvard and at Christ Church, Oxford, as a Fellowship holder, getting my bachelor and graduate degrees in history and literature. At the same time, my work for magazines has given me some practical experience in that less rarefied atmosphere of American journalism. In both spheres I have watched the convention of revolt harden into a dogmatic ritual.

Revolt now has its hierarchy of saints, including such divergent apostles of Progress as the editors of the Nation and of the New Masses . It has its elaborate, formalized incantations, its holy slogans. Behind much of it today lies the smug convention that our only alternative to fascist terror is Marxism. Marxism means many things. I revolt against its 'revolt' primarily for its materialistic assault on all our non-economic values of the spirit. Economic values alone make life possible, but the moral, aesthetic, and intellectual values alone make it worth living.

The Hitler-Stalin pact and Russia's invasion of Finland have laid bare the incompetence of our 'fellow travelers' as analysts, prophets, and leaders. By Stalin's non-communist fellow travelers I specifically mean those liberals whose attitude was best summarized by the following manifesto in the Nation of August 26, 1939:—

> Reactionaries ... have encouraged the fantastic falsehood ... that the fascist states and Soviet Russia equally menace the democratic way of life. Soviet and fascist policies are diametrically opposed. The Soviet Union continues as always to be a bulwark against war and aggression, and works unceasingly for a peaceful international order.

This manifesto had four hundred prominent signers. They were the 'Four Hundred' of liberalism's Social Register. Being men of integrity, many disillusioned signers should become ardent recruits for a saner movement to conserve civil liberties from the cornmunazi method of 'direct action.' Among those signers for whom dictator Stalin is suddenly no longer the Sir Gallahad of 'true' democracy (mighty handy word, 'true'!) are Vincent Sheean, Max Lerner, Frederick Schuman, Louis Fischer, and (just before his death) Heywood Broun. In the interest of all democratic readers, I sincerely petition the Nation to publish another poll of these four hundred influential writers to inquire how many still uphold that cocksure manifesto.

Last year the fellow travelers were still the bosses of Student Unions and the American Youth Congress. I was dismissed as an unenlightened reactionary for my 'fantastic' notion that the German and Russian state-socialisms are basically alike in economics and in ruthless methods. Similarly, the leftists were the 'respectable' people in the world of letters. They were the fashionable folk who 'counted'; and the fact cannot be disguised that it paid and still pays, in certain pressure groups, to be a 'persecuted' Marxist.

We are witnessing strange and terrible events. It is the deluge time, the time of the breaking of nations. How few at those swanky cocktail parties for Loyalist Spain foresaw that the OGPU's sacred Party Line might be what lost democracy to Hitler, Franco, Stalin! Today all those young disciples of revolt's fashionable Four Hundred must reexamine their premises from a fresh perspective. I write from the point of view of millions of ordinary young college graduates trying sincerely to answer two questions: What values are enduring enough to survive all these crashing panaceas? What means must we use to save these precious values?

II

With these two questions in mind, let me begin by asking: What do I mean by 'conservative'? Conservatism must include what Thomas Mann calls humanism: the conservation of our cultural, spiritual, and individualist heritage. Common sense is notoriously the oracle of conservatism. But, at its best, common sense means no mere unimaginative shrewdness. It means the common and universal sense of mankind, the common values basic to every civilized society and creed. These human values are the traffic lights which all (even 'mass movements') must obey in order that all may be free. The New Masses would dismiss this common-sense conservatism as bigoted and 'reactionary.' Very well, then, but against what am I reactionary?

Even during the height of Russia's pretensions to 'peace and democracy' I have consistently reacted against the self-styled liberalism of the fellow travelers. Today I would make no exception in favor of any of communism's rival versions, so long as communists, like the brilliant Mr. Granville Hicks, merely repudiate Stalin's foreign policy and fail to repudiate Lenin's formulae of class war and proletarian dictatorship.

Equally, I react against the self-styled Liberty Leaguers. The latter give us only the negative liberty to starve and be unemployed. They accept our American concept of democratic equality, but in the following negative sense: America's impartial Liberty League democracy forbids the Sixty Families equally with the California share-croppers to steal bread. It punishes the coupon-clipping millionaire as well as the unemployed mechanic for sleeping on a park bench or begging in the subway. It gives us the equal right and complete liberty to buy America's plentiful wheat crop - much of which is burnt because we lack the money to buy it. Let us frankly grant that Europe's dictators and revolutions remedy many of these evils. However, my conservatism includes my faith that America can and must remedy these evils within our constitutional framework of Law and civil liberties.

The conservative's principle of principles is the necessity and supremacy of Law and of absolute standards of conduct. I capitalize 'Law,' and I mean it. Suppose it were proved that the eternal absolutes do not really exist. Instinctively we should say: So much the worse for them. But now we must learn to say: So much the worse for existence! We have learned that from sad experience of centuries. Paradoxically, we have learned that man can only maintain his material existence by guiding it by the materially nonexistent: by the absolute moral laws of the spirit.

In America, we try to prove that 'It can't happen here' by citing the vast extent of our compulsory education. Truly, we are almost as well educated a people as the pre-Hitler Germans, and, like the Soviets, we are constantly increasing our educational institutes. 'What matters more, however, is that never was our system so inadequate as today in teaching discrimination and absolutes of conduct.

We teach a child to, read and are surprised at the enormous circulation of the Yellow Press and the Father Coughlins. We are bred as little evolutionary Progressives, but we don't discriminate in what direction we breathlessly rush 'forward.' The explanation is that we are no longer given the standards for discriminating. Fertile soil for freedom and for mutual tolerance is never in human nature to start with, but must be painstakingly ploughed over for centuries. The history of mass movements affords vastly more evidence for original sin than for any natural goodness of man. Education's job is austerely to restrict, not fulfill, the child's 'glorious self-expression.'

Freedom of thought we must never restrict in America. Conduct and action we can and must restrict. Instead of 'progressive education' our democratic school system must instill, from kindergarten on, the necessity of limiting all human conduct and instinct by objective Law. Only so can we learn, the decent rules of the game as an unbreakable habit. By 'Law' I do not mean all existing laws. All are not necessarily good. By 'Law' I mean the legal way as a way to whatever goals we may seek; I mean it as a way of living. This way is necessarily freedom's prerequisite. In this sense, Law must tread pitilessly upon individuals, nations, classes. It must trample with callous and sublime indifference upon their economic interests yes, even their economic interests- and their 'healthy instincts of the race.'

Soft-hearted liberals are too ready to say that a lawbreaker 'means well,' that his corruption is due to his social environment and bad companions; they talk too much about his honest fanaticism, his honest non-awareness of Law. Today such qualification leads to overemphasis of the more irrelevant side of the question: the personal side. Too often it is assumed that the 'have-not' is automatically exempt from all eternal laws of humanity, whether it be a 'have-not' nation or economic class or individual. We who are old-fashioned enough to call a crime a crime are labeled as warmongers or hypocrites or dupes of propaganda. Obviously the more relevant question is simply whether or not the legal way is being violated. In fact, those few groups strong enough to carry off a violent revolution successfully are also (almost invariably) strong enough to change the rules legally to fit their new game.

The 'instinctive, unwritten sense of justice' we hear so much about is basically, and always will be, mere glorified lynch law. In instinct, every new 1940 baby is still born a caveman. Law and tradition are the slow accumulation of civilized habits, the few thousand years' habits which alone prevent the 1940 baby from remaining a caveman. Since this accumulation is haphazard, it includes—as radicals correctly accuse—much evil as well as good. But the good and the bad in tradition are often interwoven inextricably by the past. And the past cannot be changed—not even by radicals with a Harvard accent.

You weaken the magic of all good laws every time you break a bad one, every time you allow mob lynching of even the guiltiest criminal. I said 'magic' deliberately. Social stability rests to some extent on the aura surrounding our basic institutions. Such aura-wreathed pillars of tradition in various modern nations are the United States Supreme Court, an established Church, monarchy, a nonpartisan civil service and the aristocracy trained from birth to fill it. This social cement of tradition is too essential for every well-meaning, humanitarian Torn, Dick, and Harry to tinker with. It keeps us from relapsing into the barbarism inherent in our simian nature and in all mob 'awakenings.'

As menacing as open anarchists are those who discredit traditional institutions, not by attack, but by excess exploitation. The man who uses our institutions and Law as a barrier to, instead of a vehicle for, democratic reform is the real anarchist. I don't care a hoot whether any country, including ours, decides to use capitalism or socialism or any other material-ism, so long as it is attained through the vehicle of the traditional framework; so long as it is orthodoxly baptized and knighted by the magic wand of tradition; so long as it does not live 'without the Law.' I repeat: if moral absolutes do not exist, it is not so much the worse for them, but so much the worse for existence.

III

During the nineteenth century, all external standards and absolutes were one by one sacrificed at the altar of dynamic 'Life.' A pseudo-Darwinian war of all against all, for survival of the most ferocious or most lucky, becomes exalted as a healthy expression of dynamic Life-force. I suggest coining 'dynamism' as the label for this new, unchristian religion, this cult of power, instinct, blind change, blind Life. Dynamism means energy and, change for their own sake. It means playing the grand man-of-action merely for action's sake, the deification of such men-of-action as Fuhrers . Among dynamism's current incarnations is the unrestrained egoism of persons, nations, and classes. Gangsterism becomes a heroic romantic duty.

Society, as 1 would conserve it, would rest on five great self-disciplines: rule of reason in the individual, Christian ethics between individuals, Law in the state, free parliamentary negotiation among political parties, peace by negotiation among nations. Dynamism smashes all five of these great self-disciplines. Today the Nazis most radically incarnate dynamism. No wonder a current best seller refers to their 'Revolution of Nihilism'!

Dynamism, I believe, will some day be recognized as the most destructive and 'radical' revolution of modern times. It strikes at the root. Its modern rival, Marxism, retains at least the traditional respect for reason. The basis of the western world is the disciplining of life's energies and instincts by the supremacy of rational and ethical Law. Here our Christianity combines and conserves the legalistic heritage of the Jews and of the Greco-Roman Empire. In contrast, dynamism glories in the revolt of expansive Life-force against Law's 'dead shackles.' Transferred from individual to nation, such dynamism becomes lynch law: the 'healthy' and natural mob instincts of what Nazis call 'the Volk ' and Reds call 'the masses.'

With the most passionate intensity, I resent the no-third-way sophistry of forcing American students to choose only from the alternatives of fascists and Marxists. Dynamic fascism, as it is sweeping Europe, is idealism diabolized. Economism, its opposite, whether of capitalist or Marxist brand, is materialism deified. Dynamism is immoral, economic materialism is unmoral; take your choice! Both are present to some degree in all societies. Either in excess explodes the civilization we conservatives would conserve. Our fight as young Americans is twofold: against our established cult of economism and mammon worship, and against all attempts to import fascism in its place.

In one aspect, the challenge of frank and open Bolshevik church burning is almost less dangerous to us than the more subtly masked Nazi challenge. This mask is anti-Semitism. Those ostrich conservatives miss its whole point who whistle in the dark, thinking 'What concern of ours are racial persecutions so long as we're not persecuted?' Political anti-Semitism is no isolated program. It is the first step in an ever-widening revolt of mob instinct against all restraints and liberties. It is the thin opening wedge for the subversion of democracy, Christianity, and tolerance in general.

I said our civilization is based on a blend of legalism, reason, and the Christian discipline (Protestant or Catholic or the closely-related Jewish). I stated this as a simple objective fact. Whether belief in them is 'true' is quite another matter, which each individual must decide for himself. Their truth will always be disputable, in so far as they deal with the non-material and invisible, but their necessity is indisputable.

IV

What are the immediate political duties today of a common-sense conservative? I think a conservative should patriotically join in our country's cautious groping toward a planned economy. Despite party slogans, this groping will in practice steadily continue, whether under Republicans or New Dealers. Leftists try to discredit the conservative attitude by linking it in the public mind with laissez-faire economics. But how on earth can we conserve what's dead and what probably never existed? Purchasing power must be so distributed that every citizen is himself a free and stable property owner and an economically articulate consumer. Necessities (such as wheat) must no longer be burned or ploughed under, but sold, even without profit and below cost, to all citizens who lack them.

Accepting vigilance as the price of liberty, the conservative will be alert equally against all illegalities from all sides, whether from flag-waving Americans or 'aliens' or capitalists or labor unions. He will everywhere answer illegal force with force-in-law, returning words for words and bullets for bullets,

until Law is respected again. He will answer fascist attacks, from within the United States or without, with the policeman's club and not the Chamber.. lain umbrella.

Suppose the Communist Party calls itself the 'Paul Reveres of 1936,' and the Nazi Bund pays lip service to George Washington. No matter how democratic their phrases or how American their ancestry, our conservative will judge solely by their methods and actions. Anti-fascist lip service is not enough of a criterion. If fascism ever comes to America, it will assuredly be some homespun, native brand, riding into power on militaristic anti-fascist (i.e. anti-'alien') phrases. The same is true of any native American communist dictatorship; it would vociferously repudiate any openly labeled 'communist' party. So we have only one safe criterion, no matter what are men's professed aims and programs. That criterion is whether they pursue those aims within or without the great American constitutional framework.

Our conservative will never admit that the state as a whole is greater than the sum of its separate individuals. All power he will distrust and hence limit. He will fight every extension of government authority, no matter in whose hands, whenever it seems more dangerous than the genuine wrong it would remedy. But he will insist equally on forestalling mass discontent with thoroughgoing social legislation, with the proviso that such new governmental power be as decentralized as possible.

He believes in majority rule for America, but never majority dictatorship. Instead, he believes in the absolute constitutional and human rights of minorities, whether share-croppers or millionaires, whether economic, religious, or racial. He will stubbornly insist that corrupt means betray even the worthiest ends. Karl Marx's disciples would discredit our constitutional and judicial checks merely because irresponsible finance can abuse them. That is like blaming the abused glass; it tackles the wrong cause of the evil. The fact that wealthy Wall Street or radical Norman Thomas or anybody else happens to benefit from free speech does not automatically make free speech vicious.

V

This year all 'ideology' is in flux. Soon, justified by Russian events, conservatives will no longer seem disgracefully unfashionable in intellectual spheres. But let's not gloat over honest disillusionment. Instead, let us conservatives humbly admit that we have equally erred. Our error was our tardiness in realizing the economic lesson of our 1929 crash.

Current Congressional investigations go too far in smearing duped fellow travelers with the communist brush. It is bad morals and bad strategy to allow red-baiting to pass into liberal-baiting and labor-baiting. That only drives labor and the uncrushable mass of liberal voters into a revolutionary camp. Instead, we must offer them our own camp as freedom's refuge from the communism with which they flirted so disastrously. For both decency and strategy, conservatives should repudiate our liberal-baiting rabble rousers unambiguously, be they eloquent Senators or cheap sensational journalists.

To sum up: my great dream, perhaps young and naive, is for American youth to synthesize cultural, spiritual, and political conservatism with economic reform. Such a movement must simultaneously be broad enough to include some economic ends of the radicals and narrow enough to exclude the means of the communazis. Our generation's New Conservatism must appeal not only to independent-minded conservatives but also-to those disillusioned 'fellow travelers.' The former must accept further economic planning and honestly repudiate their pre-1929 cant. The latter must honestly repudiate despotic Russia and Marxist materialism and the stirring up of a lawless mob movement: their pre-1939 cant.

Only such concessions from both sides can make harmonious synthesis possible within our free representative system. In all democracies, men of good will from right and left must today unite to conserve their free habits of centuries. Conserve from what? From the extreme reaction of what I call the 'capitalist anarchists' and from the extreme radicalism of the dynamists.

The success of literal 'National Socialists' whether Hitler or Stalin, is in their vote-getting synthesis of romantic expansive nationalism with a planned economy. In contrast, we conservatives must synthesize the good in the latter, not with despotism, but with freedom—that is, with all our ancient civil liberties, tolerance of minorities, and a peaceful internationalism of Law. Our job is to prove right here in America that democracy means, not destructive wrangling, but effective cooperation in solving our spiritual and economic problems. Can this be too much to hope from American youth? It is not yet too late.

The URL for this page is http://www.theatlantic.com/doc/194004/peter-viereck .

SUBSCRIBE TO THE ATLANTIC TODAY!
Take advantage of our great rate to subscribe to a year of The Atlantic Monthly. Go to the following Web address to sign up today:
http://www.theatlantic.com/subscribe12

All material copyright The Atlantic Monthly Group. All rights reserved.